import "Turbine";
import "Turbine.Gameplay";

Settings = class();

function Settings:Constructor()
	self:Load();
end

function Settings:Load()
	self.settingsTable = Turbine.PluginData.Load(Turbine.DataScope.Account,"ChallengeTracker");
	
	self.currentPlayer = Turbine.Gameplay.LocalPlayer:GetInstance():GetName();
	
	if(self.settingsTable == nil) then
		self.settingsTable = {};
		self.settingsTable.players = {};
		self.settingsTable.players.length = 0;
		self.settingsTable.instances = {};
		self.settingsTable.instances.length = 0;
		self.settingsTable.resetSchedule = {};
		self.settingsTable.locks = {};
		self:LoadInstances();
	end
	
	self:AddPlayer(self.currentPlayer);
end

function Settings:LoadInstances()
	self:AddInstance("The Tower of Orthanc: Fire/Frost","Weekly");
	self:AddInstance("The Tower of Orthanc: Lightning","Weekly");
	self:AddInstance("The Tower of Orthanc: Acid","Weekly");
	self:AddInstance("The Tower of Orthanc: Shadow","Weekly");
	self:AddInstance("The Tower of Orthanc: Saruman","Weekly");
	self:AddInstance("The Foundry","Bi-Weekly");
	self:AddInstance("Dargnakh Unleased","Bi-Weekly");
	self:AddInstance("Pits of Isengard","Bi-Weekly");
	self:AddInstance("Fangorn's Edge","Bi-Weekly");
	self:AddInstance("Draigoch's Lair","Weekly");
	self:AddInstance("Helegrod: Thorog","Weekly");
	self:AddInstance("Helegrod: Drake Wing","Weekly");
	self:AddInstance("Helegrod: Giant Wing","Weekly");
	self:AddInstance("Helegrod: Spider Wing","Weekly");
	self:AddInstance("Ford of Bruinen","Weekly");
	self:AddInstance("Siege of Gondamon","Weekly");
	self:AddInstance("Trouble in Tuckborough","Weekly");
	self:AddInstance("Stand at Amon Sul","Weekly");
	self:AddInstance("Strike Against Dannenglor","Weekly");
	self:AddInstance("Protectors of Thangulhad","Weekly");
	self:AddInstance("Breaching the Necromancer's Gate","Weekly");
	self:AddInstance("Assault on the Ringwraith's Lair","Weekly");
	self:AddInstance("The Battle in the Tower","Weekly");
	self:AddInstance("Survival: Barrow-Downs","Weekly");
	self:AddInstance("Defence of the Prancing Pony","Weekly");
	self:AddInstance("Thievery and Mischief","Weekly");
	self:AddInstance("Rescue in Nurz Ghashu","Weekly");
	self:AddInstance("Battle of the Deep-Way","Weekly");
	self:AddInstance("Battle of the Way of the Smiths","Weekly");
	self:AddInstance("Battle of the Twenty-First Hall","Weekly");
	self:AddInstance("The Icy Crevasse","Weekly");
	self:AddInstance("Attack at Dawn","Weekly");
	
	
	
	self:ResetLocks();
end

function Settings:AddInstance(name,reset)
	self.settingsTable.instances[self.settingsTable.instances.length] = name;
	self.settingsTable.instances.length = self.settingsTable.instances.length + 1;
	self.settingsTable.resetSchedule[name] = reset;
end	

function Settings:AddPlayer(player)
	for i=0, self.settingsTable.players.length-1 do
		if(self.settingsTable.players[i] == player) then
			return
		end
	end
	self.settingsTable.players[self.settingsTable.players.length] = player; self.settingsTable.players.length = self.settingsTable.players.length + 1;
	for i=0, self.settingsTable.instances.length-1 do
		local instance = self.settingsTable.instances[i];
		if(self.settingsTable.locks[instance] == nil) then
			self.settingsTable.locks[instance] = {};
		end
		self.settingsTable.locks[instance][player] = false;
	end
	self:Save();
end

function Settings:ResetLocks()
	for i=0, self.settingsTable.instances.length-1 do
		local instance = self.settingsTable.instances[i];
		for j=0, self.settingsTable.players.length-1 do
			local player = self.settingsTable.players[j];
			if(self.settingsTable.locks[instance] == nil) then
				self.settingsTable.locks[instance] = {};
			end
			self.settingsTable.locks[instance][player] = false;
		end
	end
	self:Save();
end

function Settings:Save()
	Turbine.PluginData.Save(Turbine.DataScope.Account, "ChallengeTracker", self.settingsTable);
end


function Settings:AddLock(player,instance)
	if(self.settingsTable.locks[instance] == nil) then
		self.settingsTable.locks[instance] = {};
	end
	self.settingsTable.locks[instance][player] = true;
	self:Save();
end

function Settings:RemoveLock(player,instance)
	if(self.settingsTable.locks[instance] == nil) then
		self.settingsTable.locks[instance] = {};
	end
	self.settingsTable.locks[instance][player] = false;
	self:Save();
end

function Settings:ResetWeekly()
	self:ResetLocks();
end

function Settings:ResetBiWeekly()
	for i=0, self.settingsTable.instances.length-1 do
		local instance = self.settingsTable.instances[i];
		if(self.settingsTable.resetSchedule[instance] == "Bi-Weekly") then
			for j=0, self.settingsTable.players.length-1 do
				local player = self.settingsTable.players[j];
				if(self.settingsTable.locks[instance] == nil) then
					self.settingsTable.locks[instance] = {};
				end
				self.settingsTable.locks[instance][player] = false;
			end
		end
	end
	self:Save();
end